#!/usr/local/bin/oraperl

# gen.rpt.pl: generate the OFFNET monthly report

$ORAID 	= 'T:event.merit.edu:oracle7';
$acct 	= 'netstats';
$pwd 	= 'net2net';

$lda = &ora_login($ORAID, $acct, $pwd) || die $ora_errstr;

# get the number of silent nets for previous month
$csr = &ora_open($lda, "select count(*) from silent_net3")
	|| die $ora_errstr;

@sil_num = &ora_fetch($csr);
warn $ora_errstr if $ora_errno;
&ora_close($csr) || die $ora_errstr;

# print out header
print "
Remarks: 
     - These stats are generated from the raw data collected by OFFNET
       every  15 minutes.

     - Silent nets refer to these nets that were configed before the
       beginning of the month but had never been announced to the
       backbone during the month.

     - In the following tables,
           Upper Bound of Active Nets := Config - Silent_net
       The 'active nets' are so defined since the concept
       is tied to a certain period of time.

print "\n(2) Number of Silent Nets of the Month: $sil_num[0] \n";

(3) T3 Routing Table Stat:

                      Upper Bound
Date         Config   Active Nets    Max    Avg    Min
--------   ---------- ----------- ------ ------ ------ \n";

$csr = &ora_open($lda, 
	"select to_char(c.rundate, 'mm/dd/yy'),
	avg(c.t3config), avg(c.t3config) - :1,  
	max(s.t3route),
	round(avg(s.t3route)), min(s.t3route)
	from net3_stat s, net3_config c
	where to_char(c.rundate, 'mm/yy') =
	(select to_char(add_months(sysdate, -1), 'mm/yy') from dual)
	and  to_char( s.rundate, 'mm/dd/yy') = to_char(c.rundate, 'mm/dd/yy')
	group by to_char(c.rundate, 'mm/dd/yy')
	order by to_char(c.rundate, 'mm/dd/yy')")
	|| die $ora_errstr;

&ora_bind($csr, $sil_num[0]);

while (@data = &ora_fetch($csr)) {
    	print join("\t", @data), "\n";
}
warn "$ora_errstr" if $ora_errno;
&ora_close($csr)        || die $ora_errstr;

# path stat
print "\n";
print "(4)  T3 Pathway Stat:

             Primary Path    Secondary Path       3rd Path         
Date       Max   Avg   Min   Max   Avg   Min   Max   Avg   Min  
--------  ----- ----- ----- ----- ----- ----- ----- ----- ----- \n";

$csr = &ora_open($lda,
	"select to_char(rundate, 'mm/dd/yy'),  
    	round(max(100*firstpath/(t3route - t3unconfig)), 1), 
    	round(avg(100*firstpath/(t3route - t3unconfig)), 1), 
    	round(min(100*firstpath/(t3route - t3unconfig)), 1),
    	round(max(100*secondpath/(t3route - t3unconfig)), 1), 
    	round(avg(100*secondpath/(t3route - t3unconfig)), 1), 
    	round(min(100*secondpath/(t3route - t3unconfig)), 1), 
    	round(max(100*thirdpath/(t3route - t3unconfig)), 1), 
    	round(avg(100*thirdpath/(t3route - t3unconfig)), 1),
    	round(min(100*thirdpath/(t3route - t3unconfig)), 1)
	from net3_stat
	where to_char(rundate, 'mm/yy') =
	(select to_char(add_months(sysdate, -1), 'mm/yy') from dual)
    	group by  to_char(rundate, 'mm/dd/yy')
    	order by  to_char(rundate, 'mm/dd/yy')")
	|| die $ora_errstr;

while (@data = &ora_fetch($csr)) {
	print "$data[0]";
	for ($i = 1; $i < 10; $i++) {
		printf "  %4.1f", $data[$i];
	}
	print "\n";
}
warn "$ora_errstr" if $ora_errno;
&ora_close($csr)        || die $ora_errstr;

# reload into silent_net3 (monthly)

&ora_do($lda, "drop table silent_net3") 
	|| die $ora_errstr;

&ora_do($lda, 
	"create table silent_net3 as
	 select netnum from net_comp3_now n
	 where not exists 
	 (select netnum from binary3_dump b 
	  where n.netnum = b.netnum)")
	|| die $ora_errstr; 

&ora_do($lda, 
	"create index sill3 on silent_net3(netnum)")
	|| die $ora_errstr;

&ora_commit($lda);

&ora_logoff($lda) || die $ora_errstr;














